@@ -7,10 +7,9 @@ from odoo_report_helper.report import Report
 
 class EqReport(Report):
     def __init__(self, entry_name, report_name: str, report_type: str, model_name: str, company_id, eq_export_type="pdf",
-                 print_report_name="Report", attachment="Report.pdf", eq_ignore_images=True, eq_ignore_html=False,
-                 eq_export_complete_html=False, eq_export_as_sql=True, multi_print=False, attachment_use=False,
-                 eq_print_button=False, dependencies=[], model_fields={}, calculated_fields={},
-                 eq_merge_data_from_multi=False):
+                 print_report_name="Report", attachment="Report.pdf", eq_ignore_images=True, eq_handling_html_fields='standard', multi=False, attachment_use=False,
+                 eq_print_button=False, dependencies=False, model_fields={}, calculated_fields={},
+                 eq_multiprint='standard'):
         self.entry_name = entry_name
         self.report_name = report_name
         self.report_type = report_type
@@ -19,12 +18,10 @@ class EqReport(Report):
         self.eq_export_type = eq_export_type
         self.attachment = attachment
         self.eq_ignore_images = eq_ignore_images
-        self.eq_ignore_html = eq_ignore_html
-        self.eq_export_complete_html = eq_export_complete_html
-        self.eq_export_as_sql = eq_export_as_sql
-        self.multi_print = multi_print
+        self.eq_handling_html_fields = eq_handling_html_fields
+        self.multi = multi
         self.attachment_use = attachment_use
-        self.eq_merge_data_from_multi = eq_merge_data_from_multi
+        self.eq_multiprint = eq_multiprint
         self.eq_print_button = eq_print_button
         self._fields = model_fields
         self._calculated_fields = calculated_fields
@@ -42,13 +39,12 @@ class EqReport(Report):
             'report_type': self.report_type,
             'print_report_name': self.print_report_name,
             'model': self.model_name,
+            'company_id': self.company_id[0] if self.company_id else False,
             'eq_export_type': self.eq_export_type,
             'eq_ignore_images': self.eq_ignore_images,
-            'eq_ignore_html': self.eq_ignore_html,
-            'eq_export_complete_html': self.eq_export_complete_html,
-            'eq_export_as_sql': self.eq_export_as_sql,
-            'eq_merge_data_from_multi': self.eq_merge_data_from_multi,
-            'multi': self.multi_print,
+            'eq_handling_html_fields': self.eq_handling_html_fields,
+            'eq_multiprint': self.eq_multiprint,
+            'multi': self.multi,
             'attachment': self.attachment,
             'attachment_use': self.attachment_use,
             'eq_print_button': self.eq_print_button
@@ -63,18 +59,16 @@ class EqReport(Report):
             'report_model': self.model_name,
             'eq_export_type': self.eq_export_type,
             'eq_ignore_images': self.eq_ignore_images,
-            'eq_ignore_html': self.eq_ignore_html,
-            'eq_export_complete_html': self.eq_export_complete_html,
-            'eq_export_as_sql': self.eq_export_as_sql,
-            'eq_merge_data_from_multi': self.eq_merge_data_from_multi,
-            'multiprint': self.multi_print,
+            'eq_handling_html_fields': self.eq_handling_html_fields,
+            'eq_multiprint': self.eq_multiprint,
+            'multi': self.multi,
             'attachment': self.attachment,
             'attachment_use': self.attachment_use,
             'eq_print_button': self.eq_print_button,
-            'dependencies': [],
+            'dependencies': self._dependencies,
             'report_fields': self._fields,
             'calculated_fields': self._calculated_fields
         }
         if self.company_id:
-            yaml_data = {k: v for k, v in (list(yaml_data.items())[:5] + [('company_id', [self.company_id.id])] + list(yaml_data.items())[5:])}
+            yaml_data = {k: v for k, v in (list(yaml_data.items())[:5] + [('company_id', self.company_id)] + list(yaml_data.items())[5:])}
         return yaml_data
